@@ -393,11 +393,38 @@ def main():
     long_read_group.add_argument(
         '-z', '--longread-type', '--longread_type', '--long_read_type', '--long-read-type',
         help='Whether the sequencing platform and technology for the longreads. \n'
-             '"rs" for PacBio RSII, "sq" for PacBio Sequel, "ccs" for PacBio CCS \n'
+             '"rs" for PacBio RSII, "sq" for PacBio Sequel, "ccs" for PacBio CCS, "hifi" for PacBio HiFi \n'
              'reads, "ont" for Oxford Nanopore and "ont_hq" for Oxford Nanopore high quality reads (Guppy5+ or Q20) \n',
         dest='longread_type',
         default="ont",
-        choices=["ont","ont_hq", "rs", "sq", "ccs"],
+        choices=["ont","ont_hq", "rs", "sq", "ccs", "hifi"],
+    )
+
+    long_read_group.add_argument(
+        '--medaka-model', '--medaka_model',
+        help='Medaka model to use for polishing long reads. \n',
+        dest='medaka_model',
+        default="r941_min_hac_g507",
+        choices=[
+            "r103_fast_g507", "r103_fast_snp_g507", "r103_fast_variant_g507", "r103_hac_g507", "r103_hac_snp_g507",
+            "r103_hac_variant_g507", "r103_min_high_g345", "r103_min_high_g360", "r103_prom_high_g360", "r103_prom_snp_g3210",
+            "r103_prom_variant_g3210", "r103_sup_g507", "r103_sup_snp_g507", "r103_sup_variant_g507", "r1041_e82_260bps_fast_g632",
+            "r1041_e82_260bps_fast_variant_g632", "r1041_e82_260bps_hac_g632", "r1041_e82_260bps_hac_variant_g632", "r1041_e82_260bps_sup_g632",
+            "r1041_e82_260bps_sup_variant_g632", "r1041_e82_400bps_fast_g615", "r1041_e82_400bps_fast_g632",
+            "r1041_e82_400bps_fast_variant_g615", "r1041_e82_400bps_fast_variant_g632", "r1041_e82_400bps_hac_g615",
+            "r1041_e82_400bps_hac_g632", "r1041_e82_400bps_hac_variant_g615", "r1041_e82_400bps_hac_variant_g632", "r1041_e82_400bps_sup_g615",
+            "r1041_e82_400bps_sup_variant_g615", "r104_e81_fast_g5015", "r104_e81_fast_variant_g5015", "r104_e81_hac_g5015",
+            "r104_e81_hac_variant_g5015", "r104_e81_sup_g5015", "r104_e81_sup_g610", "r104_e81_sup_variant_g610", "r10_min_high_g303",
+            "r10_min_high_g340", "r941_e81_fast_g514", "r941_e81_fast_variant_g514", "r941_e81_hac_g514", "r941_e81_hac_variant_g514",
+            "r941_e81_sup_g514", "r941_e81_sup_variant_g514", "r941_min_fast_g303", "r941_min_fast_g507", "r941_min_fast_snp_g507",
+            "r941_min_fast_variant_g507", "r941_min_hac_g507", "r941_min_hac_snp_g507", "r941_min_hac_variant_g507", "r941_min_high_g303",
+            "r941_min_high_g330", "r941_min_high_g340_rle", "r941_min_high_g344", "r941_min_high_g351", "r941_min_high_g360", "r941_min_sup_g507",
+            "r941_min_sup_snp_g507", "r941_min_sup_variant_g507", "r941_prom_fast_g303", "r941_prom_fast_g507", "r941_prom_fast_snp_g507",
+            "r941_prom_fast_variant_g507", "r941_prom_hac_g507", "r941_prom_hac_snp_g507", "r941_prom_hac_variant_g507", "r941_prom_high_g303",
+            "r941_prom_high_g330", "r941_prom_high_g344", "r941_prom_high_g360", "r941_prom_high_g4011", "r941_prom_snp_g303", "r941_prom_snp_g322",
+            "r941_prom_snp_g360", "r941_prom_sup_g507", "r941_prom_sup_snp_g507", "r941_prom_sup_variant_g507", "r941_prom_variant_g303",
+            "r941_prom_variant_g322", "r941_prom_variant_g360", "r941_sup_plant_g610", "r941_sup_plant_variant_g610"
+        ]
     )
 
     long_read_group.add_argument(
@@ -653,7 +680,7 @@ def main():
              'High long read coverage during assembly indicates that the overlap layout consensus algorithm \n'
              'is more likely to be correct.',
         dest='min_cov_long',
-        default=20
+        default=5
     )
 
     assemble_group.add_argument(
@@ -661,7 +688,7 @@ def main():
         help='Automatically include Flye contigs with short read coverage less than or equal to this. \n'
              'Low coverage via short reads indicates that metaSPAdes will not be able to better assemble this contig.',
         dest='min_cov_short',
-        default=3
+        default=5
     )
 
     assemble_group.add_argument(
@@ -669,7 +696,7 @@ def main():
         help='Automatically exclude Flye contigs with long read coverage less than or equal to this \n'
              'and less than or equal to `--exclude-contig-size`',
         dest='exclude_contig_cov',
-        default=100
+        default=10
     )
 
     assemble_group.add_argument(
@@ -677,14 +704,14 @@ def main():
         help='Automatically exclude Flye contigs with length less than or equal to this \n'
              'and long read coverage less than or equal to `--exclude-contig-cov`',
         dest='exclude_contig_size',
-        default=25000
+        default=2500
     )
 
     assemble_group.add_argument(
         '--include-contig-size', '--include_contig_size',
-        help='Automatically include Flye contigs with length less than or equal to this',
+        help='Automatically include Flye contigs with length greater than or equal to this',
         dest='include_contig_size',
-        default=100000
+        default=10000
     )
 
     #~#~#~#~#~#~#~#~#~#~#~#~#~   sub-parsers   ~#~#~#~#~#~#~#~#~#~#~#~#~#
@@ -709,7 +736,7 @@ def main():
         help='Main workflow to run',
         dest='workflow',
         nargs="+",
-        default=['complete_assembly'],
+        default=['complete_assembly_with_qc'],
     )
 
     ##########################  ~ RECOVER ~   ###########################
