@@ -9,7 +9,7 @@ elif snakemake.params.long_read_type == 'ont_hq':
     subprocess.Popen(
         "flye --nano-hq %s --meta -o data/flye -t %d" %
         (snakemake.input.fastq, snakemake.threads), shell=True).wait()
-elif snakemake.params.long_read_type == 'ccs':
+elif snakemake.params.long_read_type == 'ccs' or snakemake.params.long_read_type == 'hifi':
     subprocess.Popen(
         "flye --pacbio-hifi %s --meta -o data/flye -t %d" %
         (snakemake.input.fastq, snakemake.threads), shell=True).wait()
