@@ -5,7 +5,7 @@ if snakemake.config["long_reads"] != "none" and not os.path.exists("data/long_co
     if snakemake.config["long_read_type"][0] in ["ont", "ont_hq"]:
         subprocess.Popen("TMPDIR=%s coverm contig -t %d -r %s --single %s -p minimap2-ont -m length trimmed_mean variance --bam-file-cache-directory data/binning_bams/ --discard-unmapped --min-read-percent-identity 0.85 > data/long_cov.tsv" %
                          (snakemake.params.tmpdir, snakemake.threads, snakemake.input.fasta, " ".join(snakemake.config["long_reads"])), shell=True).wait()
-    elif snakemake.config["long_read_type"][0] in ["rs", "sq", "ccs"]:
+    elif snakemake.config["long_read_type"][0] in ["rs", "sq", "ccs", "hifi"]:
         subprocess.Popen("TMPDIR=%s coverm contig -t %d -r %s --single %s -p minimap2-pb -m length trimmed_mean variance --bam-file-cache-directory data/binning_bams/ --discard-unmapped --min-read-percent-identity 0.9 > data/long_cov.tsv" %
                          (snakemake.params.tmpdir, snakemake.threads, snakemake.input.fasta, " ".join(snakemake.config["long_reads"])), shell=True).wait()
     else:
