@@ -159,8 +159,10 @@ class Processor:
 
         try:
             self.longread_type = args.longread_type
+            self.medaka_model = args.medaka_model
         except AttributeError:
             self.longread_type = 'none'
+            self.medaka_model = 'none'
 
         try:
             self.short_percent_identity = args.short_percent_identity
@@ -315,6 +317,7 @@ class Processor:
         conf["short_reads_2"] = self.pe2
         conf["long_reads"] = self.longreads
         conf["long_read_type"] = self.longread_type
+        conf["medaka_model"] = self.medaka_model
         conf["kmer_sizes"] = self.kmer_sizes
         conf["use_megahit"] = self.use_megahit
         conf["coassemble"] = self.coassemble
